@@ -23,7 +23,8 @@ the scope, to make sure it can be used without.
 
 Note: This is using "optparse", because "argparse" is only Python 2.7 and
 higher, and we still support Python 2.6 due to the RHELs still being used,
-and despite the long deprecation, it's in every later release.
+and despite the long deprecation, it's in every later release, and actually
+pretty good.
 """
 
 import os
@@ -36,6 +37,7 @@ from nuitka.PythonFlavors import (
     isApplePython,
     isCPythonOfficialPackage,
     isDebianPackagePython,
+    isFedoraPackagePython,
     isHomebrewPython,
     isMSYS2MingwPython,
     isNuitkaPython,
@@ -75,6 +77,8 @@ def _getPythonFlavor():
         return "WinPython"
     elif isDebianPackagePython():
         return "Debian Python"
+    elif isFedoraPackagePython():
+        return "Fedora Python"
     elif isHomebrewPython():
         return "Homebrew Python"
     elif isApplePython():
@@ -224,7 +228,10 @@ for Scons. Otherwise Nuitka can use what you run Nuitka with or a "scons"
 binary that is found in PATH, or a Python installation from Windows registry.""",
 )
 
-parser.add_option(
+warnings_group = OptionGroup(parser, "Control the warnings to be given by Nuitka")
+
+
+warnings_group.add_option(
     "--warn-implicit-exceptions",
     action="store_true",
     dest="warn_implicit_exceptions",
@@ -233,7 +240,7 @@ parser.add_option(
 Enable warnings for implicit exceptions detected at compile time.""",
 )
 
-parser.add_option(
+warnings_group.add_option(
     "--warn-unusual-code",
     action="store_true",
     dest="warn_unusual_code",
@@ -242,7 +249,7 @@ parser.add_option(
 Enable warnings for unusual code detected at compile time.""",
 )
 
-parser.add_option(
+warnings_group.add_option(
     "--assume-yes-for-downloads",
     action="store_true",
     dest="assume_yes_for_downloads",
@@ -254,8 +261,23 @@ from nul device, e.g. "</dev/null" or "<NUL:". Default is to prompt.""",
 )
 
 
+warnings_group.add_option(
+    "--nowarn-mnemonic",
+    action="append",
+    dest="nowarn_mnemonics",
+    metavar="MNEMONIC",
+    default=[],
+    help="""\
+Disable warning for a given mnemonic. These are given to make sure you are aware of
+certain topics, and typically point to the Nuitka website. The mnemonic is the part
+of the URL at the end, without the HTML suffix. Can be given multiple times and
+accepts shell pattern. Default empty.""",
+)
+
+parser.add_option_group(warnings_group)
+
 include_group = OptionGroup(
-    parser, "Control the inclusion of modules and packages in result."
+    parser, "Control the inclusion of modules and packages in result"
 )
 
 include_group.add_option(
@@ -451,6 +473,23 @@ empty.""",
 parser.add_option_group(data_group)
 
 
+dll_group = OptionGroup(parser, "DLL files")
+
+dll_group.add_option(
+    "--noinclude-dlls",
+    action="append",
+    dest="dll_files_inhibited",
+    metavar="PATTERN",
+    default=[],
+    help="""\
+Do not include DLL files matching the filename pattern given. This is against
+the target filename, not source paths. So ignore a DLL "someDLL" contained in
+the package "package_name" it should be matched as "package_name/someDLL.*".
+Default empty.""",
+)
+
+parser.add_option_group(dll_group)
+
 execute_group = OptionGroup(parser, "Immediate execution after compilation")
 
 execute_group.add_option(
@@ -1213,7 +1252,6 @@ windows_group.add_option(
 )
 
 windows_group.add_option(
-    "--windows-onefile-tempdir-spec",
     "--onefile-tempdir-spec",
     action="store",
     dest="onefile_tempdir_spec",
@@ -1330,6 +1368,7 @@ parser.add_option_group(macos_group)
 linux_group = OptionGroup(parser, "Linux specific controls")
 
 linux_group.add_option(
+    "--linux-icon",
     "--linux-onefile-icon",
     action="append",
     dest="icon_path",
@@ -1338,16 +1377,6 @@ linux_group.add_option(
     help="Add executable icon for onefile binary to use. Can be given only one time. Defaults to Python icon if available.",
 )
 
-linux_group.add_option(
-    "--linux-onefile-compression",
-    action="store",
-    dest="app_image_compression",
-    choices=("gzip", "xz"),
-    metavar="COMPRESSION",
-    default="gzip",
-    help="Compression method to use for Linux onefile builds. Defaults to gzip for faster decompression",
-)
-
 parser.add_option_group(linux_group)
 
 plugin_group = OptionGroup(parser, "Plugin control")
